@@ -1,3 +1,4 @@
+from ..core.object import Object, AccessSpecifier
 
 
 class TranslatorBase(object):
@@ -47,13 +48,18 @@ class TranslatorBase(object):
                     values.append(1 << shift)
                 elif cast == 'string':
                     member.initial_value = '"{}"'.format(member.name)
-            elif cast == 'int':
-                # TODO if initialization is as enumerate of others members need throw error (example: one|two)
-                values.append(member.initial_value)
             else:
-                member.initial_value = 'None'
+                # TODO if initialization is as enumerate of others members need throw error (example: one|two)
+                cast = 'int'
+                values.append(member.initial_value)
 
             shift += 1
+        value = Object()
+        value.initial_value = '{}::{}'.format(cls.name, cls.members[0].name)
+        value.name = '_value'
+        value.type = cast
+        value.access = AccessSpecifier.private
+        cls.members.append(value)
         return values
 
     @staticmethod
