@@ -1,4 +1,3 @@
-from .generator_predefined_files import GeneratorPredefinedFiles
 from ..base.generator import GeneratorBase
 from ..base.generator_visitor import GeneratorVisitor
 from .generator_data_storage import GeneratorDataStorage
@@ -6,7 +5,7 @@ from .generator_factory import GeneratorFactory
 from .generator_package import GeneratorPackage
 from .generator_observer import GeneratorObserver
 from .generator_operator_equals import GeneratorOperatorEquals
-from ..core.class_ import Class
+from .generator_predefined_files import GeneratorPredefinedFiles
 
 
 class Generator(GeneratorBase):
@@ -15,7 +14,6 @@ class Generator(GeneratorBase):
         GeneratorBase.__init__(self)
 
     def generate(self, model):
-        self.generate_base_enum_class(model)
         GeneratorBase.generate(self, model)
         GeneratorDataStorage().generate(model)
         GeneratorVisitor().generate(model, False)
@@ -24,10 +22,3 @@ class Generator(GeneratorBase):
         GeneratorObserver().generate(model)
         GeneratorOperatorEquals().generate(model)
         GeneratorPredefinedFiles().generate(model)
-
-    def generate_base_enum_class(self, model):
-        base_enum = Class()
-        base_enum.name = 'BaseEnum'
-        base_enum.type = 'class'
-        model.add_class(base_enum)
-
