@@ -31,21 +31,6 @@ class RegexPatternPython(object):
         (re.compile(r'if\s*\(\s*(.+)\s*\)'), r'if \1:', ['if']),
         (re.compile(r'if\s*!(.+):'), r'if not \1:', ['if']),
         (re.compile(r'else'), r'else:', ['else']),
-        (re.compile(r'in_map\s*\(\s*(.+?),\s*(.+?)\s*\)'), r'(\1 in \2)', ['in_map']),
-        (re.compile(r'in_list\s*\(\s*(.+),\s*(.+)\s*\)'), r'(\1 in \2)', ['in_list']),
-        (re.compile(r'list_push\s*\(\s*(.+?),\s*(.+)\s*\)'), r'\1.append(\2)', ['list_push']),
-        (re.compile(r'list_insert\s*\(\s*(.+?),\s*(.+)\s*,\s*(.+)\s*\)'), r'\1.insert(\2, \3)', ['list_insert']),
-        (re.compile(r'list_remove\s*\(\s*(.+),\s*(.+)\s*\)'), r'\1.remove(\2)', ['list_remove']),
-        (re.compile(r'list_erase\s*\(\s*(.+),\s*(.+)\s*\)'), r'\1.remove(\1[\2])', ['list_erase']),
-        (re.compile(r'list_truncate\s*\(\s*(.+),\s*(.+)\s*\)'), r'\1 = \1[:\2]', ['list_truncate']),
-        (re.compile(r'list_clear\s*\(\s*(.+)\s*\)'), r'\1 = list()', ['list_clear']),
-        (re.compile(r'list_size\s*\('), r'len(', ['list_size']),
-        (re.compile(r'list_resize\s*\(\s*(.+),\s*(.+)\s*\)'), r'\1 = [None for _ in range(int(\2))]', ['list_resize']),
-        (re.compile(r'map_size\s*\('), r'len(', ['map_size']),
-        (re.compile(r'map_clear\s*\(\s*(.+)\s*\)'), r'\1 = dict()', ['map_clear']),
-        (re.compile(r'map_remove\s*\(\s*(.+),\s*(.+)\s*\)'), r'\1.pop(\2, None)', ['map_remove']),
-        (re.compile(r'string_empty\((.+?)\)'), r'(not (\1))', ['string_empty']),
-        (re.compile(r'string_size\((.+?)\)'), r'len(\1)', ['string_size']),
         (re.compile(r'std::string (\w+);'), r'\1 = ""', ['std::string']),
         (re.compile(r'(\w+)\s+(\w+);'), r'\2 = \1()'),
         (re.compile(r'(\w+) = return\(\)'), r'return \1', ['return']),
