@@ -282,8 +282,6 @@ def get_cpp(with_ctr):
 #include "mg_Factory.h"
 #include "Test.h"
 #include "mg_extensions.h"
-#include "SerializerJson.h"
-#include "SerializerXml.h"
 
 namespace mg
 {
@@ -341,10 +339,6 @@ def get_hpp():
 
 namespace mg
 {
-    class SerializerXml;
-    class DeserializerXml;
-    class SerializerJson;
-    class DeserializerJson;
 
     class Test
     {
